Abstract
1
Introduction
1.1
What is Stormwater?
1.2
Urban stormwater runoff is a two-fold problem, impacting the quantity of water pulsing off the land, as well as the quality of that water.
1.2.1
Water Quantity
1.2.2
Water Quality
1.3
Toxic Stormwater Impacts
1.4
Moving forward- identifying where stormwater pollution is generated on the landscape
1.5
Building an interactive tool to service stormwater manager needs:
1.6
Open data helps us bound forward
2
High-resolution Land Cover
2.1
Overview
2.2
Land Cover Development
2.3
Validation and Accuracy Assessment
3
References
(Appendix) Appendix
4
Appendix A - Regional HSPF Calibration Factors
5
Appendix B - Instructions for Accessing Tabulated Hydrology Results via BigQuery
Tabulated Results via BigQuery
Schema
Querying Tabulated Results
Querying Geometry
Stormwater Heatmap Technical Reference
(Appendix) Appendix